AuthStorage class

Constructors

AuthStorage({String tokenIdentifier = 'Token', required AndroidOptions aOptions})

Properties

emptyToken → Token
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future
loadTokenFromCache<T extends Token>() → Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveTokenToCache(Token token) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited